@@ -16,9 +16,9 @@ from __future__ import absolute_import
 import os
 import sys
 import unittest
+from unittest import mock
 
 import fixtures
-import mock
 import testtools
 from testtools import content
 
